<?php
add_action('admin_menu', function() {
    add_submenu_page('cfb-forms', 'Edit Fields', 'Edit Fields', 'manage_options', 'cfb-edit-fields', 'cfb_render_edit_fields_page');
});

function cfb_enqueue_field_editor_assets($hook) {
    if (isset($_GET['page']) && $_GET['page'] === 'cfb-edit-fields') {
        wp_enqueue_script(
            'cfb-admin',
            plugins_url('admin.js', dirname(__FILE__)) . '?v=3',
            ['jquery', 'jquery-ui-sortable'],
            null,
            true
        );
    }
}
add_action('admin_enqueue_scripts', 'cfb_enqueue_field_editor_assets');

function cfb_render_edit_fields_page() {
    $form_id = $_GET['form'] ?? '';
    if (!$form_id) {
        echo '<div class="notice notice-error"><p>Missing form ID.</p></div>';
        return;
    }

    $fields_key = 'cfb_fields_' . $form_id;
    $fields = get_option($fields_key, []);

    if (isset($_POST['save_fields'])) {
        check_admin_referer('cfb_save_fields_action');
        $fields = array_map(function($item) {
            return json_decode(stripslashes($item), true);
        }, $_POST['fields'] ?? []);
        update_option($fields_key, $fields);
        echo '<div class="notice notice-success"><p>Fields saved.</p></div>';
    }

    ?>
    <div class="wrap">
        <h1>Edit Fields for: <?php echo esc_html($form_id); ?></h1>
        <a class="button" href="<?php echo site_url('/wp-admin/admin-ajax.php?action=preview_form&id=' . esc_attr($form_id)); ?>" target="_blank">Preview Form</a>
        <form method="post" id="cfb-field-form">
            <?php wp_nonce_field('cfb_save_fields_action'); ?>
            <p>
                <input type="text" name="new_label" placeholder="Label">
                <select name="new_type">
                    <option value="text">Text</option>
                    <option value="textarea">Textarea</option>
                    <option value="checkbox">Checkbox</option>
                    <option value="select">Dropdown</option>
                </select>
                <label><input type="checkbox" name="new_required"> Required</label>
                <input type="text" name="new_options" placeholder="Options (comma-separated)">
                <button id="add-field-btn" class="button">Add</button>
            </p>
            <ul id="cfb-fields-list">
                <?php foreach ($fields as $f): ?>
                    <li class="cfb-field-item">
                        <strong><?php echo esc_html($f['label']); ?></strong> (<?php echo esc_html($f['type']); ?>)
                        <?php if (!empty($f['required'])): ?> <em>[required]</em><?php endif; ?>
                        <?php if (!empty($f['options'])): ?> [<?php echo esc_html(implode(', ', $f['options'])); ?>]<?php endif; ?>
                        <input type="hidden" name="fields[]" value='<?php echo esc_attr(json_encode($f)); ?>'>
                        <span class="cfb-remove" style="margin-left: 10px; cursor:pointer;">×</span>
                    </li>
                <?php endforeach; ?>
            </ul>
            <p><input type="submit" name="save_fields" class="button button-primary" value="Save Fields"></p>
        </form>
    </div>
    <?php
}
?>
