<?php
add_shortcode('cfc_form', function($atts) {
    $form_id = $atts['id'] ?? '';
    if (!$form_id) return '';

    $fields = get_option('cfb_fields_' . $form_id, []);
    if (empty($fields)) return '';

    $uikit_enabled = get_option('cfc_form_uikit_enabled');

    ob_start();
    ?>
    <form method="post" class="<?php echo $uikit_enabled ? 'uk-form-stacked' : ''; ?>">
        <input type="hidden" name="_cfb_form_id" value="<?php echo esc_attr($form_id); ?>">
        <?php foreach ($fields as $f): 
            $name = sanitize_title($f['label']);
            $required = !empty($f['required']) ? 'required' : '';
            ?>
            <label class="<?php echo $uikit_enabled ? 'uk-form-label' : ''; ?>">
                <?php echo esc_html($f['label']); ?>
            </label><br>
            <?php if ($f['type'] === 'textarea'): ?>
                <textarea name="<?php echo esc_attr($name); ?>" <?php echo $required; ?> class="<?php echo $uikit_enabled ? 'uk-textarea' : ''; ?>"></textarea>
            <?php elseif ($f['type'] === 'checkbox'): ?>
                <?php foreach ($f['options'] as $option): ?>
                    <label class="uk-margin-small-right">
                        <input class="uk-checkbox" type="checkbox" name="<?php echo esc_attr($name); ?>[]" value="<?php echo esc_attr($option); ?>"> <?php echo esc_html($option); ?>
                    </label>
                <?php endforeach; ?>
            <?php elseif ($f['type'] === 'select'): ?>
                <select name="<?php echo esc_attr($name); ?>" <?php echo $required; ?> class="<?php echo $uikit_enabled ? 'uk-select' : ''; ?>">
                    <?php foreach ($f['options'] as $option): ?>
                        <option value="<?php echo esc_attr($option); ?>"><?php echo esc_html($option); ?></option>
                    <?php endforeach; ?>
                </select>
            <?php else: ?>
                <input type="text" name="<?php echo esc_attr($name); ?>" <?php echo $required; ?> class="<?php echo $uikit_enabled ? 'uk-input' : ''; ?>">
            <?php endif; ?>
            <br><br>
        <?php endforeach; ?>
        <button type="submit" class="<?php echo $uikit_enabled ? 'uk-button uk-button-primary' : ''; ?>">Submit</button>
    </form>
    <?php
    return ob_get_clean();
});
?>
